
# q-expansion of newform 8004.2.a.d, downloaded from the LMFDB on 10 May 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 8004
weight = 2
poly_data = [-4, 18, -10, -35, 19, 19, -8, -3, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0], 1], [[0, 1, 0, 0, 0, 0, 0, 0], 1], [[50, -108, -131, 131, 79, -46, -13, 5], 2], [[-56, 106, 133, -131, -79, 46, 13, -5], 2], [[50, -102, -122, 126, 76, -45, -13, 5], 1], [[-104, 210, 273, -269, -171, 98, 29, -11], 2], [[-132, 272, 317, -339, -195, 120, 33, -13], 2], [[71, -143, -175, 179, 107, -64, -18, 7], 1]]

hecke_ring_character_values = None
aps_data = [[0, 0, 0, 0, 0, 0, 0, 0], [1, 0, 0, 0, 0, 0, 0, 0], [-1, 0, 0, 0, 0, 0, 0, -1], [0, 0, 0, 0, 0, 0, 1, 1], [0, 0, 0, -1, 0, 0, 0, 1], [-1, 0, 0, 0, 1, 0, 0, 0], [-1, 2, 0, 1, -1, 0, -1, 0], [-1, -1, 0, 1, 1, -1, -1, -1], [1, 0, 0, 0, 0, 0, 0, 0], [1, 0, 0, 0, 0, 0, 0, 0], [0, 0, -1, 1, -2, -1, -1, -1], [-2, 0, -1, -1, 0, 2, 1, 1], [-1, -4, 0, 1, 0, 1, 0, -1], [-1, -1, 0, 0, -2, 2, -1, -1], [-2, 0, 2, 0, -1, 2, -3, -1], [-1, -4, -1, 1, 1, -1, 1, 0], [2, 0, 0, -3, 3, -2, 4, 2], [0, -1, 1, -2, 2, 0, -1, -1], [-1, -2, 0, -2, 2, 2, 3, 0], [0, 3, 1, 3, -3, 0, -3, 1], [-5, 5, -4, -1, 0, 0, 1, 3], [-2, 4, -1, 0, -3, 1, -3, 1], [2, 0, -2, -3, 3, -2, 7, 4], [-2, 1, 1, 6, -2, -2, -1, 0], [0, 0, 3, 2, -2, -1, -4, -3], [0, -2, -3, -4, 5, -3, 7, 4], [1, 3, 2, 1, -3, -1, -4, 1], [-4, 1, 2, 4, 0, 0, -6, -6], [-2, 1, 1, -2, 0, 0, 0, 0], [-2, 0, -1, 0, 2, -2, 0, 2], [-3, 1, 4, 1, 2, -2, 3, -1], [-3, 1, 2, 0, 0, 3, 0, 0], [-3, 1, 1, -2, 1, 0, 0, -2], [-8, 4, -1, -1, -1, 1, 0, -2], [-2, -2, 4, 0, -1, 6, -2, 0], [-4, -4, 0, 2, 0, -2, -1, -4], [1, -4, 1, -3, 3, -3, 4, 4], [-9, 0, -4, 4, 3, -3, -1, -3], [-3, 7, -1, 1, -2, -1, -4, 4], [1, -7, 3, 0, -2, 2, 0, 0], [-7, -4, -3, -4, 2, 3, 1, 0], [-2, 2, -3, 0, -3, -2, -4, 2], [1, 1, -4, -2, 4, -5, 4, 1], [2, 0, 7, 1, -6, 4, -2, -1], [-6, 5, -7, 2, 2, -3, 1, 3], [-7, 1, -4, 2, 0, 2, -1, -4], [-5, 1, 2, -4, -4, 3, 3, -1], [-8, 3, 0, -4, -1, 0, -4, -1], [2, 0, 4, 3, -7, 3, -6, -6], [-2, -3, 4, -3, 0, 4, 2, -2], [3, -1, 2, -1, -1, -2, 4, -3], [-3, -6, 4, 5, 0, 3, -1, -3], [-4, -1, -6, -6, 5, -2, 5, 5], [3, -8, 5, 6, 0, 6, -1, -5], [-7, 8, -5, -5, 1, 0, 5, 8], [5, 1, -1, -3, 1, -8, 4, 2], [-2, 1, -1, -2, 0, -1, 9, 8], [-3, -7, 2, 1, 4, 5, 0, -3], [1, -6, 2, -3, 5, -3, 2, 2], [-6, 0, -10, -5, 4, -1, 6, 6], [-7, -8, 4, 4, 1, 4, -2, -7], [8, 1, 7, -3, -4, 1, -7, 0], [-4, -3, 1, 3, 3, -10, 0, -7], [3, -1, 4, -5, -2, 6, 0, 4], [-2, -3, 1, 5, -1, 1, 2, 0], [-2, -5, 1, 7, 2, 1, 0, -8], [-10, 3, 0, 4, 4, -3, 3, -2], [-2, -3, 4, 4, 8, -5, 2, -6], [-5, 8, -7, 0, 0, -5, -3, 2], [-2, 5, 2, 8, -13, 3, -10, -6], [3, -2, 5, 2, -7, 4, -1, -6], [8, -1, 1, -6, -2, 1, 7, 3], [-7, 12, -10, 0, 1, -1, 7, 7], [5, -1, 5, 2, -10, 2, -3, -4], [-6, -4, -1, -3, 9, 0, 7, 1], [-2, -6, -5, 2, 1, -1, -2, -7], [-15, 9, -1, 7, -4, 6, -10, -1], [1, -6, 4, 2, 1, 5, -3, -1], [-1, 14, -3, 0, -1, -8, -1, 6], [8, 8, -3, -2, -3, -6, 5, 13], [4, 1, 4, -2, -11, 7, -3, 2], [-13, 0, 4, 0, 0, 1, -10, -9], [7, -2, 6, 1, -2, 4, -3, -9], [3, 0, 0, -1, -4, 2, -3, -1], [8, -8, 6, 5, -2, 2, 3, -7], [3, -15, 3, 2, 4, 5, 1, -3], [-6, -1, -8, -10, 2, 2, 7, 9], [-10, 5, -5, 1, 2, 1, 10, 0], [-5, 6, -5, -7, -1, 1, -7, -4], [-6, 6, -2, -2, 3, -3, 5, 5], [-8, -6, -5, 0, 5, -2, -4, -3], [4, 15, -11, -1, -4, -1, 7, 11], [-8, 9, -3, 4, 2, -4, -1, -5], [1, -4, 2, 2, 7, -2, 2, -9], [0, -5, 9, -1, -7, 8, 0, -6], [1, 5, -13, -3, 9, -10, 12, 7], [-5, 0, -6, -12, 5, -4, 7, 11], [5, -1, 2, 0, -1, 5, 7, -3], [10, -3, -2, 2, -1, -5, -6, -3], [7, 9, 0, 8, -2, -8, -4, -3], [0, 2, -5, -6, -5, 0, 5, 6], [1, -8, 11, 3, -2, 0, -2, -12], [7, 0, 5, -6, 1, 0, 5, 3], [-8, 2, -2, 6, 1, -7, -2, -5], [-10, 1, -1, 0, 5, 5, 2, 5], [4, 0, -6, -5, -1, 4, -1, 4], [1, 1, 7, 1, 2, -5, -4, -2], [1, 6, -8, -3, 2, 3, 5, 5], [2, 12, -5, -1, 1, -2, 3, 12], [-14, -7, 2, 3, 3, 6, -1, -2], [-2, 6, -10, 0, -3, -1, 3, 0], [4, 0, -8, -3, 6, -10, -2, -3], [0, -6, -5, -8, 11, -5, 8, 11], [10, 12, 8, -6, -2, -6, 3, 12], [-7, -1, -3, 1, 3, 3, -2, -1], [5, 2, 0, 7, -4, -4, -5, -2], [1, 0, 1, -8, -9, 9, -1, 1], [5, -6, 2, 2, -5, 6, -9, -5], [-4, 6, 2, 2, -5, 4, -9, -13], [8, 6, 7, 8, -10, 3, -14, -10], [14, -17, 6, 3, 4, 0, -2, -5], [-5, 5, -2, -8, 2, 1, 1, 10], [4, -8, 11, 3, -8, 15, -6, -8], [0, 4, 5, -2, -5, -3, -10, -5], [-5, 0, -4, -2, 2, -6, 1, 0], [-11, 10, -3, 0, 5, -1, -2, 2], [-1, 10, -5, -4, 2, -3, 10, 18], [12, 9, -3, 7, 2, -4, -5, 3], [-2, -1, -2, -4, 1, 9, 9, 8], [5, -6, 15, -1, -5, 3, -1, -8], [-2, -3, 5, 1, -5, 3, -5, -1], [2, -11, 0, -5, 12, 0, 5, 1], [1, -11, -1, 13, 2, 8, -7, -12], [14, -7, 5, -4, 5, 10, 10, 11], [11, -3, 3, -9, 1, 11, 8, 10], [-10, -3, 4, 5, 7, 2, 4, -6], [23, -1, -9, 3, -3, -8, 2, 6], [4, -4, -3, 0, 0, -1, 12, 9], [14, -8, 2, -1, 4, -5, 8, -6], [0, -13, 18, 3, -5, 5, -9, -13], [2, 6, -6, 0, -1, 1, -12, 5], [1, -13, -2, 3, 8, -2, -2, -15], [14, 0, 1, -3, 1, -1, 15, 17], [14, 4, 6, 6, -11, -1, -18, -14], [-3, 13, 0, -2, 2, -2, -2, -3], [1, 11, -13, -5, 3, 5, 6, 7], [3, 0, -14, -10, 6, -7, 11, 11], [2, -19, -6, -5, 12, 2, 13, 8], [-7, -3, -3, -2, 5, -2, 13, 2], [-7, 3, 1, 11, -7, 10, -10, -4], [-5, 7, 2, 3, -12, -5, -21, -5], [0, 0, 7, 3, -5, 12, -4, -16], [-8, -22, 2, -3, 13, 5, 5, 0], [7, -1, 8, 0, -6, 6, -3, -2], [-6, -5, 0, 2, -10, 1, 0, 6], [1, 4, -13, -6, 1, -6, 11, 5], [10, -3, -1, -11, 6, -6, 15, 6], [-18, 1, -1, 9, -8, 6, -9, -11], [6, -1, -7, 5, 3, -16, 3, 2], [14, 21, 3, 1, -10, -1, -5, 11], [8, 7, -3, 12, -8, -7, -9, 4], [5, 16, 1, -3, -5, -4, -12, 6], [-1, 8, -3, -1, -1, -8, -6, 6], [-6, 9, -8, 4, 7, -5, 5, 6], [6, -5, -3, 7, -6, 0, -6, -7], [24, 5, 1, -5, 1, 0, 9, 5], [-2, 3, -7, 6, 0, -21, -5, -6], [-6, -2, 19, 6, -5, 9, -8, -5], [-8, 10, -2, 5, 0, -2, -2, 1], [14, -6, 2, 7, -2, -5, 1, -5], [0, -11, 4, 13, 7, 1, -12, -20], [7, 2, 9, 6, -2, -7, 4, -1], [18, -9, -4, -2, 5, -2, 10, 10], [-8, 5, -9, -1, 4, 5, 4, 9], [5, -9, 4, 9, 3, -7, 6, -5], [10, -9, 6, -4, -5, -5, -1, 0], [-1, 9, 1, -7, 2, -3, 1, 7], [-2, -9, 6, -4, -8, 7, -2, -13], [11, -8, 1, -4, 2, 14, 13, 12], [17, 1, -3, -3, -7, -7, -2, 3], [13, 0, 5, 4, 2, 4, -5, -4], [-2, 2, -6, -12, -5, 8, -6, -1], [-4, 4, -3, -2, 3, -2, -4, 0], [-11, 2, 8, -3, -7, 7, 1, -11], [25, -3, 12, 4, 4, 1, -7, -7], [1, 3, 0, -12, 5, -4, -2, 11], [-11, -4, -1, 3, -9, 4, -8, -4], [-2, -4, -2, 4, 12, -4, 2, 10], [1, 7, 13, 5, -19, 6, -16, -16], [9, 1, 12, 15, -14, 9, -24, -13], [-15, 4, 4, -7, 8, -5, 4, 2], [-5, -6, -16, -8, 10, 9, 8, 6], [14, -6, 1, -6, 1, -13, 14, 9], [-18, 1, -6, -3, 13, -5, 11, 3], [-2, -1, 3, 7, 1, 5, -9, -8], [13, 1, -3, -17, -3, 11, 9, 12], [-1, 2, 1, 14, -1, -16, -3, -4], [-11, 12, -5, -5, -3, 8, -3, -3], [7, 8, 1, -2, 1, -14, 1, 2], [0, -9, 6, -11, 7, 9, 9, 0], [-13, 4, -5, 5, 6, -6, 1, 6], [-10, -10, -9, -2, 11, -2, 17, 8], [18, -6, -8, -16, 14, -9, 27, 16], [-11, 8, 1, -8, 1, 2, 12, 24], [13, -14, 10, 8, 0, 11, 5, -10], [-18, 6, -6, 7, 2, -2, -12, -10], [-3, 8, -5, -6, 10, 0, 0, 4], [27, 4, 4, -5, -2, -7, -11, 7], [6, -18, 18, -1, -8, 2, -6, -8], [-16, 11, -2, 3, 3, -3, 10, 18], [11, -5, 2, -7, 2, 0, 13, 15], [1, -3, 9, -7, 4, -1, 4, 10], [9, 0, -3, -3, 17, -17, 8, 2], [-5, -2, 15, 3, 0, 7, -13, -13], [0, 12, -8, 2, -10, 6, -1, 3], [-11, -3, -12, -1, 11, -11, 5, 8], [-7, 2, -12, -3, 0, -3, 4, 0], [-1, 5, -10, -13, 7, -7, 17, 14], [21, 11, -6, 7, 2, -8, -1, 17], [-2, 9, 1, 7, -12, 1, -16, -4], [-9, -3, 0, 0, -4, 8, -18, -13], [2, -3, -3, 9, 7, -2, 1, 4], [8, -11, -17, -5, 20, 2, 13, 10], [10, -4, 12, 8, -4, -2, -9, -2], [-12, 0, 2, 6, 0, 5, 4, 4], [-34, 6, -2, 7, 0, 4, -5, -2], [-26, 7, 8, 2, -7, 0, -5, -16], [-15, 6, 1, 6, -4, 1, 2, 0], [22, -26, 4, -10, 11, 4, 17, -4], [5, 2, 4, 6, 3, 1, 1, -11], [0, 5, -18, -8, 10, -16, 14, 4], [19, -17, 6, -12, -3, 12, 8, 7], [26, -7, 10, -1, -4, -2, 6, -6], [-22, 8, -4, 8, 3, -7, 7, 2], [16, -7, 6, 3, 6, -10, -10, -11], [10, 1, -6, -1, -3, 3, -7, -1], [5, 11, 1, -5, -13, 2, -13, 12], [21, -5, 6, -2, 1, -7, 0, 7], [6, 1, -5, 2, -7, -7, -21, 5], [8, -23, 7, -7, 3, 4, 5, -12], [9, 1, -1, 7, 3, -4, 2, -5], [20, -7, 11, -9, -12, 7, -4, 1], [-24, 2, 0, 2, 1, 7, -25, -17], [21, -21, 6, -1, 0, -8, 15, -1], [14, -16, 1, -5, -3, 4, 4, 3], [23, -13, 11, -15, 2, 9, 8, 6], [13, -20, 5, -13, 18, -3, 9, -4], [-2, -5, 7, -8, -9, 7, -12, -9], [19, 3, 1, -1, 4, -6, 7, 9], [17, -10, -9, -8, 8, -4, 25, 11], [-9, 25, -11, 3, -4, -2, 8, 18], [-26, 8, -6, 1, -8, 8, -11, 4], [22, -8, 12, -17, 4, 3, 2, 11], [-7, 9, -4, 2, 9, -12, -2, -7], [-8, 6, -1, 6, -18, 0, -21, -23], [-2, 2, -21, -5, 11, -4, 12, 11], [0, 11, 3, 0, 1, 6, -5, -11], [4, -1, 3, 5, -12, 11, -17, -1], [-4, -10, -5, -7, 21, -5, 10, 7], [0, 7, 1, 10, -9, -9, -18, -10], [5, -15, 9, 3, -3, 2, -14, -4], [0, 10, 2, 14, -12, -2, -6, -19], [1, -9, 12, 10, 1, -5, -1, -4], [-8, -3, 0, 8, -7, 3, -9, -32], [12, -21, 3, -3, 10, -2, 4, -9], [-18, 20, -12, 6, 0, -16, -3, 6], [-10, 2, -1, -1, -3, -8, 6, -12], [-10, 9, -11, -7, -1, 0, 9, 9], [-14, 14, 6, 20, -25, 0, -24, -10], [-4, 17, -7, 16, -17, 0, -11, -1], [-3, -7, -17, 10, 5, 4, 5, -5], [-14, 3, 7, 13, -9, 8, -33, -22], [-8, 1, 5, 7, -2, -1, -3, 1], [18, -11, 7, 5, -3, 7, -14, -13], [-3, 4, -5, 9, -4, -3, -5, 0], [18, -16, -4, -9, 15, -5, 12, -10], [-21, -7, -5, -1, 17, -12, 22, 4], [-4, 0, 20, 2, -13, 17, -6, -7], [11, -6, 6, 14, -11, -3, 5, -5], [9, 22, -17, -3, 3, -16, 4, 16], [31, -12, 5, 12, -6, 0, -19, -12], [18, -17, 1, 8, 4, -2, -8, -4], [-18, 28, -5, 3, 1, 0, -2, 1], [4, -1, 1, 25, -8, -1, -2, -2], [-8, 8, 4, -14, -5, 16, 10, 4], [8, -32, 16, -1, 8, 11, 3, -23], [17, 11, -1, -15, -1, -2, -3, 14], [-24, -9, 3, 13, 5, 1, -19, -20], [10, 5, 8, -3, -11, 7, -9, 9], [1, 3, 10, 13, -3, -4, -4, 1], [-4, 13, -2, -3, 7, -1, 2, 18], [28, -15, 3, -19, 5, -4, 26, 9], [10, 1, 7, -4, 3, 11, -3, 17], [21, -3, -10, -10, -2, 9, -4, 7], [14, -2, 13, 5, -2, -2, -6, -13], [-21, 14, 6, -9, 11, -4, 15, 5], [-2, -7, 8, 5, 1, -14, 8, -10], [0, 17, 9, 7, -19, 6, -27, -11], [6, -3, -16, -14, 23, -21, 27, 18], [-13, 4, -7, -23, 4, 1, 1, -4], [24, 26, -9, -1, -16, -2, -5, 15], [17, -11, 6, 1, -7, 4, -9, 1], [4, 3, 3, -5, -6, 23, -3, -3], [-9, 4, -10, 7, -3, 10, -3, -11], [16, 0, 6, -5, 17, -11, 8, 8], [7, 10, 17, 20, -11, 8, -28, -14], [9, 3, 5, -13, -5, 8, 3, 1], [-3, -6, -16, 4, 4, -8, 4, 9], [32, 11, 4, 1, -5, -4, 9, 18], [31, -6, -4, -21, 10, 5, 14, 4], [10, 0, -8, 14, 0, -10, -6, 8], [-6, 13, -12, -7, 12, -19, 15, 7], [-3, -6, 1, 8, 4, -4, 1, -22], [-20, 1, -2, -13, 1, 7, 8, -1], [11, -21, -11, -20, 18, 2, 17, -4], [13, 2, 8, 0, -7, 6, -5, -2], [25, -20, 4, 2, -3, 2, -2, -19], [30, 31, -4, 1, 0, -18, 3, 8], [23, -6, 16, -7, 0, 7, -3, -4], [-15, 6, -4, 2, -7, -5, -4, 12], [13, -10, -2, -8, 8, -9, -7, -1], [-7, 10, 8, 3, -16, 11, 11, 4], [-6, -17, 16, 15, -11, -9, -9, -18], [-4, 29, -15, 7, 10, -20, 2, 7], [11, -16, 4, -9, 5, -1, 12, 11], [-17, -3, 2, 22, -4, 0, -20, -17], [24, 4, 16, 14, -5, 6, -24, -22], [8, -13, 15, 22, 4, -2, -12, -19], [17, 13, -21, -2, 9, -8, 12, 17], [-25, 11, -7, 8, -8, 15, -14, -6], [-12, -4, -22, -20, 27, -6, 34, 24], [21, 13, -3, 2, -3, -2, 8, 24], [-28, 10, -13, 12, -18, 5, -13, -17], [-9, 7, 9, 12, -23, 9, -1, -7], [5, 0, 2, 13, -20, 2, -6, -9], [-10, -1, 2, 22, -3, -17, -15, -18], [-1, -21, 16, 7, 2, -1, -9, -26], [0, -20, -4, 13, 5, -4, -18, -23], [-6, -12, -1, -17, 8, 5, 1, -13], [34, 4, 2, -9, 11, -5, 15, 5], [23, -17, 18, 6, -1, -7, 5, -9], [-40, 20, -7, 9, 7, -6, 4, 3], [-4, -6, 5, 15, -7, -3, -4, 4], [-15, 9, -10, 7, -12, 8, -20, -4], [22, -5, 3, 14, -6, 9, -2, 3], [-7, 1, -10, -10, 11, -16, 18, 33], [10, 13, -13, 4, 3, -6, 7, 25], [1, -10, -15, -8, -4, 5, 20, 14], [24, 7, 7, -1, -1, -16, 13, 2], [-5, 0, 7, -6, 20, 0, 11, 11], [19, -24, 3, -17, 30, -7, 16, -4], [12, -3, 18, -2, 2, 12, -2, 17], [6, -6, 5, -5, 28, -10, 8, 1], [-8, 8, -24, 7, -2, -20, -3, 8], [-9, 8, -22, -5, 17, -12, 15, 11], [-5, -5, -14, -3, 24, -18, 23, 11], [-11, 22, -13, -2, -7, 12, 9, 15], [29, -2, -10, -8, -8, 5, 9, 21], [8, -16, 4, 6, -3, -8, 7, 3], [7, 6, 11, 3, -17, -6, -3, -16], [-2, 27, 8, 4, -16, -9, -14, -9], [-43, 11, -4, 2, -9, 6, -6, -9], [-1, 10, -8, -28, 12, 11, 16, 14], [12, 18, 8, -4, -13, 1, -19, 0], [-12, -1, 2, -15, 10, 2, 11, 8], [-29, 9, -4, 11, -9, -1, -34, -13], [-20, -13, -8, -2, 19, 4, 27, 3], [6, -7, -12, -13, 27, -2, 26, 29], [29, 6, 5, -19, -4, -3, -2, 6], [-18, 0, 11, 21, -4, -1, -13, -3], [10, 7, -6, -6, 7, -2, 18, 13], [-2, 21, -14, -14, 11, 4, 7, 12], [0, 8, -8, -1, 0, -23, 4, 19], [3, -10, -9, -9, 24, -10, 5, 17], [5, 7, 16, -4, 2, 6, -13, -5], [-6, 16, 13, 26, -25, 7, -41, -14], [8, -35, 10, 2, 2, 0, 3, -15], [12, 16, -2, -9, -3, -1, 3, 26], [3, 4, -1, -6, -14, 14, -7, 12], [3, 0, -22, -4, 16, -13, 10, 21], [19, 4, 11, 19, 0, -20, 1, -10], [6, 2, -20, -15, 32, -20, 27, 18], [-1, 9, 28, 16, -20, 13, -17, -15], [-17, 15, -22, -13, 9, -7, 11, 18], [-21, 4, 5, -6, 15, -3, 4, 8], [7, 25, -4, 15, -15, -2, 6, 7], [-10, 40, 4, 7, -7, -6, -17, 0], [-31, 17, 5, 8, 1, 12, -18, 9], [7, -8, 0, -5, -10, 18, -2, 15], [-4, -1, 21, 11, -8, 1, -17, -14], [10, -8, -1, -9, -10, 10, 21, 29], [-4, -4, -20, -8, 27, -16, 32, 30], [-19, -11, -2, 7, 10, 8, 2, -20], [-32, 14, -6, 4, -4, 5, -31, 2], [9, 11, 1, 15, -3, -12, -20, 5], [-13, 15, -17, 10, 10, -12, 12, 5], [-14, -5, -10, -4, 13, 9, 11, 0], [-3, 26, -2, 6, -3, 2, -13, 1], [5, 11, 2, -5, -24, 15, -13, 8], [-15, -4, 10, -12, 0, 7, -24, -6], [29, -10, 14, 4, -9, 1, -29, -23], [-3, 21, -6, 10, -15, 7, 5, 7], [-26, -20, -3, -10, 16, 17, 17, 1], [-31, -28, -7, 4, 9, 9, 14, -10], [25, 5, 7, -7, 7, -10, 14, 26], [-16, 16, -19, -10, -11, 9, 11, 15], [-8, -9, -4, -6, 7, -23, 10, -9], [23, -25, 16, 3, 3, 18, 14, -16], [-15, -5, -32, -9, 12, -3, 15, 13], [-39, -6, -3, -20, 8, 21, 1, 14], [-24, -23, -1, -1, 2, -6, 12, -2], [-19, 8, 1, -1, 5, -11, -7, 4], [31, -24, -2, -18, 10, -9, 35, 7], [24, -6, 4, -5, -4, -1, 14, 20], [-21, -3, -4, -4, 9, -14, 15, 3], [-16, 18, -9, -14, 15, 8, 2, 18], [6, -11, -14, -20, 19, -22, 21, 25], [-24, 0, 4, 15, -15, 12, 9, -3], [-12, 5, -20, -17, 6, 10, -1, -3], [15, 32, -6, -14, -1, -9, 15, 13], [6, -34, 18, 4, -14, 10, 0, -16], [3, -17, 3, 15, -11, 14, -3, -14], [27, 17, 4, -7, -23, 9, -14, -3], [-10, 33, -13, 7, 10, -17, -5, -1], [31, -45, 10, -9, 1, 14, 11, -14], [-2, -2, 5, 3, -13, 10, -6, 9], [-26, 6, -1, -6, -4, 5, -16, -5], [-24, 7, -15, 8, -5, -5, 3, -6], [-16, 9, 16, -3, 7, 7, -1, 7], [2, -1, 14, 18, -23, -7, -25, -28]]
